Learn R Programming

postpack (version 0.5.4)

cjs_no_rho: Example mcmc.list 2

Description

An example of samples from a joint posterior distribution from a Cormack-Jolly-Seber model. The specific context does not matter, this object is provided to show examples of 'postpack' functionality.

Usage

cjs_no_rho

Arguments

Format

A mcmc.list object.